import os

from django.views.generic import View
from django.http import HttpResponse
from django.utils import simplejson
import poppler


class PDFFormFillerEditor(View):
    def get(self, request, pdf=""):

        doc = poppler.document_new_from_file('file:///home/mark/Bedraga.pdf', password=None)
        json = simplejson.dumps(list(self.get_fields(doc, 0)), indent=4)

        return HttpResponse("<pre>" + json)


    def load_poppler_doc(self, filename):
        from django.conf import settings

        pdf_path = os.path.abspath(os.path.join(getattr(settings, 'STATIC_FORMS_ROOT', ''), filename))
        if os.path.isfile(pdf_path):
            return poppler.document_new_from_file('file://' + pdf_path, password=None)


    def generate_page_pngs(self, poppler_doc, pages=[]):
        import cairo
        import StringIO

        page = poppler_doc.get_page(pages[0] if pages else 0)
        width, height = page.get_size()
        surface = cairo.ImageSurface(cairo.FORMAT_RGB24, int(width*2), int(height*2))
        context = cairo.Context(surface)

        for page_num in pages or xrange(poppler_doc.num_pages()):
            page = poppler_doc.get_page(page_num)
            page.render(context)
            fd = StringIO.StringIO()
            surface.write(fd)
            fd.seek(0)
            yield fd


    def get_fields(self, poppler_doc, page):
        fields = poppler_doc.get_page(page).get_form_field_mapping()

        for field in fields:
            field_area = field.area
            field_data = field.field

            yield {
                'name': field_data.get_name(),
                'value': field_data.text_get_text(),
                'area': {
                    'posx': field_area.x1,
                    'posy': field_area.y1,
                    'sizew': field_area.x2 - field_area.x1,
                    'sizeh': field_area.y2 - field_area.y1,
                }
            }


